@@ -8,5 +8,5 @@ Radius = Union[float, int, np.float64]
 Vector = List[int]
 DistanceFunc = Callable[[Data, Data], Radius]
 Metric = Union[str, DistanceFunc]
-Edge = namedtuple('Edge', 'neighbor distance transition_probability')
-
+Edge = namedtuple('Edge', 'neighbor distance probability')
+CacheEdge = namedtuple('CacheEdge', 'source neighbor distance probability')
